package pps.core.base.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import pps.core.base.entity.BasePowerLineStorageEnt;
import pps.core.base.entity.BasePowerLineStorageView;
import pps.core.base.mapper.BasePowerLineStorageMapper;
import pps.core.base.mapper.BasePowerLineStorageViewMapper;
import pps.core.base.service.data.base_power_line_storage.*;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.base.data.CustomQueryInput;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XPageResult;
import xstartup.data.XServiceResult;
import xstartup.data.XSingleResult;
import xstartup.error.XError;
import xstartup.feature.api.annotation.XApiAnonymous;
import xstartup.feature.api.annotation.XApiGet;
import xstartup.feature.api.annotation.XApiPost;
import xstartup.feature.mybatis.helper.XMapperHelper;

import java.util.List;

@XService
public class BasePowerLineStorageService {
    @XApiAnonymous
    @XApiPost
    public XServiceResult createBasePowerLineStorage(XContext context, CreateBasePowerLineStorageInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        BasePowerLineStorageEnt entity = new BasePowerLineStorageEnt();
        XCopyUtils.copyObject(input, entity);
        mapper.insert(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult updateBasePowerLineStorage(XContext context, UpdateBasePowerLineStorageInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        QueryWrapper<BasePowerLineStorageEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLineStorageEnt::getId, input.getId());
        BasePowerLineStorageEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        XCopyUtils.copyObject(input, entity);
        mapper.updateById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult deleteBasePowerLineStorage(XContext context, DeleteBasePowerLineStorageInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        QueryWrapper<BasePowerLineStorageEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLineStorageEnt::getId, input.getId());
        BasePowerLineStorageEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        mapper.deleteById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetBasePowerLineStorageOutput> getBasePowerLineStorage(XContext context, GetBasePowerLineStorageInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        QueryWrapper<BasePowerLineStorageEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLineStorageEnt::getId, input.getId());
        BasePowerLineStorageEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetBasePowerLineStorageOutput output = new GetBasePowerLineStorageOutput();
        XCopyUtils.copyObject(entity, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLineStorageOutput> queryBasePowerLineStorage(XContext context, QueryBasePowerLineStorageInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        QueryWrapper<BasePowerLineStorageEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().like(BasePowerLineStorageEnt::getId, input.getId())
                .eq(BasePowerLineStorageEnt::getIsDeleted, input.getIsDeleted())
                .like(BasePowerLineStorageEnt::getCreateById, input.getCreateById())
                .like(BasePowerLineStorageEnt::getCreateByName, input.getCreateByName())
                .eq(BasePowerLineStorageEnt::getCreateTime, input.getCreateTime())
                .like(BasePowerLineStorageEnt::getModifyById, input.getModifyById())
                .like(BasePowerLineStorageEnt::getModifyByName, input.getModifyByName())
                .eq(BasePowerLineStorageEnt::getModifyTime, input.getModifyTime())
                .like(BasePowerLineStorageEnt::getLineId, input.getLineId())
                .like(BasePowerLineStorageEnt::getStorageId, input.getStorageId());
        return XMapperHelper.query(mapper, input, queryWrapper, QueryBasePowerLineStorageOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLineStorageOutput> dynamicQueryBasePowerLineStorage(XContext context, CustomQueryInput input) {
        BasePowerLineStorageMapper mapper = context.getBean(BasePowerLineStorageMapper.class);
        return XMapperHelper.query(mapper, input, BasePowerLineStorageEnt.class, QueryBasePowerLineStorageOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetBasePowerLineStorageViewOutput> getBasePowerLineStorageView(XContext context, GetBasePowerLineStorageViewInput input) {
        BasePowerLineStorageViewMapper mapper = context.getBean(BasePowerLineStorageViewMapper.class);
        BasePowerLineStorageView record = new BasePowerLineStorageView();
        XCopyUtils.copyObject(input, record);
        BasePowerLineStorageView view = mapper.selectOne(record);
        if (view == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetBasePowerLineStorageViewOutput output = new GetBasePowerLineStorageViewOutput();
        XCopyUtils.copyObject(view, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLineStorageViewOutput> queryBasePowerLineStorageView(XContext context, QueryBasePowerLineStorageViewInput input) {
        BasePowerLineStorageViewMapper mapper = context.getBean(BasePowerLineStorageViewMapper.class);
        BasePowerLineStorageView record = new BasePowerLineStorageView();
        XCopyUtils.copyObject(input, record);
        PageHelper.startPage(input.getPage(), input.getLimit());
        List<BasePowerLineStorageView> list = mapper.selectList(record);
        PageInfo<BasePowerLineStorageView> pageInfo = new PageInfo<>(list);
        List<QueryBasePowerLineStorageViewOutput> outputs = XCopyUtils.copyNewList(pageInfo.getList(), QueryBasePowerLineStorageViewOutput.class);
        return XPageResult.success(outputs, input, pageInfo.getTotal());
    }

}
